ya360
=====

Утилита командной строки для Yandex 360

    | *Для фанатов автоматизации UNIX/Linux - style или тех, кто устал курлить*

Автоматизируйте процессы администрирования Yandex 360 как вам удобно и откуда угодно, везде, где есть доступ к командной строке

Процесс установки и настройки описан в главе `Перед началом работы <https://ya360.readthedocs.io/ru/3.1.1/befo.html>`_

Документация на `ya360.readthedocs.io <https://ya360.readthedocs.io/ru/3.1.1>`_, но она вряд ли вам нужна, если знаете как пользоваться командой:

.. code-block:: console
    
    ya360 -h

Если вы вдруг обнаружили ошибку, то желательно "сдать" ее нам через `форму на github'е <https://github.com/imercury13/ya360/issues/new?assignees=&labels=&template=bug_report.md&title=>`_, а просто оставить свои пожелания и "хотелки" можно `здесь <https://github.com/imercury13/ya360/issues/new?assignees=&labels=&template=feature_request.md&title=>`_

   | *Автоматизируйте и админте. Админте и автоматизируйте. Да прибудет с вами CLI!*
